<?php
/**
 * Plugin Name: WikioVote-Button
 * Plugin URI: http://blog.ppfeufer.de/wordpress-wikiovote-button-plugin/
 * Description: This plugin will install a Wikio-Button, to vote for your posts on wikio.de. Based on the wikioVote-Script (by Wikio), edited by H.-Peter Pfeufer. Vote for articles on the wikio site.
 * Version: 2.0.2
 * Author: H.-Peter Pfeufer
 * Author URI: http://ppfeufer.de
 */

/**
 * Einige benötigte Konstanten.
 *
 * @since 1.0.0
 */
if(!defined('PPFEUFER_FLATTRSCRIPT')) {
	define('PPFEUFER_FLATTRSCRIPT', 'http://cdn.ppfeufer.de/js/flattr/flattr.js');
}

define('WIKIOVOTE_BUTTON_VERSION','2.0.2');
define('WIKIOVOTE_DONATE_PAYPAL_LINK', 'https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=N8GNRQFTS3XKS');
define('WIKIOVOTE_DONATE_FLATTR_LINK', 'http://blog.ppfeufer.de/wordpress-wikiovote-button-plugin/');

/**
 * Button Menü zum Dashboard hinzufügen.
 *
 * @since 1.0.0
 */
if(!function_exists('wikiovote_button_options')) {
	function wikiovote_button_options() {
		add_options_page('Wikio-Button', '<img src="' . plugins_url('wikiovote-button/img/wikio-icon.png') . '" id="wikio-icon" alt="Wikio Icon" width="9" height="9" /> Wikio-Button', 'manage_options', 'wikiovote-button-options', 'wikiovote_button_options_page');
	}
}

/**
 * Optionen auslesen.
 *
 * @param string $parameter
 * @since 2.0.0
 */
$var_sWikioVoteOptions = get_option('wikiovote-button-options');
if(!function_exists('wikiovote_button_get_option')) {
	function wikiovote_button_get_option($var_sParameter = '') {
		/**
		 * Prüfen ob das Formular abgesendet wurde.
		 * Wenn nicht, importiere $var_sWikioVoteOptions,
		 * ansonsten lade sie neu.
		 */
		if(!isset($_POST)) {
			global $var_sWikioVoteOptions;
		} else {
			$var_sWikioVoteOptions = get_option('wikiovote-button-options');
		}

		if ($var_sParameter == '') {
			return $var_sWikioVoteOptions;
		} else {
			return $var_sWikioVoteOptions[$var_sParameter];
		}
	}
}

/**
 * Optionsseite generieren.
 *
 * @since 1.0.0
 */
if(!function_exists('wikiovote_button_options_page')) {
	function wikiovote_button_options_page() {
		/**
		 * JavaScript für Flattr einfügen.
		 *
		 * @since 1.3.0
		 */
		if(!defined('PPFEUFER_FLATTRSCRIPT_IS_LOADED')) {
			echo '<script type="text/javascript" src="' . PPFEUFER_FLATTRSCRIPT . '"></script>';
			define('PPFEUFER_FLATTRSCRIPT_IS_LOADED', true);
		}

		/**
		 * Optionen verarbeiten.
		 *
		 * @since 2.0.0
		 */
		switch($_GET['option']) {
			/**
			 * Neues Datenbankformat schreiben.
			 *
			 * @since 2.0.0
			 */
			case 'update_db':
				wikiovote_button_update_databaseformat();

				echo '<div id="message" class="updated fade">';
				echo '<p><strong>';
				_e('Options in database updated.', 'wikiovote_button');
				echo '</strong></p>';
				echo '</div>';

				break;
		} // ENDE switch($_GET['option'])

		/**
		 * Check for new Databaseformat.
		 *
		 * @since 2.0.0
		 */
		if(!is_array(get_option('wikiovote-button-options'))) {
			echo '<div id="message" class="error fade">';
			echo '<p><strong>';
			echo sprintf(__('You have to update the options the Wikiobuttons in database. Please click %1$s.', 'wikiovote_button'),
				'<a href="' . admin_url('options-general.php?page=wikiovote-button-options&option=update_db') . '">' . __('here', 'wikiovote_button') . '</a>'
			);
			echo '</strong></p>';
			echo '</div>';
		}


		/**
		 * Status von $_POST abfangen.
		 *
		 * @since 2.0.0
		 */
		if(!empty($_POST)) {
			/**
			 * Validate the nonce.
			 *
			 * @since 2.0.0
			 */
			check_admin_referer('wikiovote-button-options');

			if($_POST['wikiovote_maintenance_reset_options']) {
				/**
				 * Resetting options to defaults.
				 *
				 * coming soon
				 */
//				wikiovote_button_reset_options();

//				echo '<div id="message" class="updated fade">';
//				echo '<p><strong>';
//				_e('Settings resetted.', 'wikiovote_button');
//				echo '</strong></p>';
//				echo '</div>';
			} elseif($_POST['wikiovote_maintenance_delete_options']) {
				/**
				 * Deleting all options from database.
				 *
				 * coming soon
				 */
//				wikiovote_button_delete_options();

//				echo '<div id="message" class="updated fade">';
//				echo '<p><strong>';
//				_e('Settings deleted.', 'wikiovote_button');
//				echo '</strong></p>';
//				echo '</div>';
			} else {
				/**
				 * Writing new options to database.
				 *
				 * @var array
				 * @since 2.0.0
				 */
				$array_Options = array(
					'wikiovote_button_pluginversion' => (string) WIKIOVOTE_BUTTON_VERSION,
					'wikiovote_button_tld' => (string) (@$_POST['wikiovote_button_tld']),
					'wikiovote_button_type' => (string) (@$_POST['wikiovote_button_type']),
					'wikiovote_button_version' => (string) (@$_POST['wikiovote_button_version']),
					'wikiovote_button_where' => (string) (@$_POST['wikiovote_button_where']),
					'wikiovote_button_rss_where' => (string) (@$_POST['wikiovote_button_rss_where']),
					'wikiovote_button_style' => (string) (@$_POST['wikiovote_button_style']),
					'wikiovote_button_display_page' => (int) (!empty($_POST['wikiovote_button_display_page'])),
					'wikiovote_button_display_front' => (int) (!empty($_POST['wikiovote_button_display_front'])),
					'wikiovote_button_display_archive' => (int) (!empty($_POST['wikiovote_button_display_archive'])),
					'wikiovote_button_display_category' => (int) (!empty($_POST['wikiovote_button_display_category'])),
					'wikiovote_button_display_feed' => (int) (!empty($_POST['wikiovote_button_display_feed'])),
				);

				wikiovote_button_update_options($array_Options);

				echo '<div id="message" class="updated fade">';
				echo '<p><strong>';
				_e('Settings saved.', 'wikiovote_button');
				echo '</strong></p>';
				echo '</div>';
			}
		} // ENDE if(!empty($_POST))
		?>
		<div class="wrap">
			<script type="text/javascript">
			function getStyle(oElm, strCssRule) {
				var strValue = "";
				if(document.defaultView && document.defaultView.getComputedStyle) {
					strValue = document.defaultView.getComputedStyle(oElm, "").getPropertyValue(strCssRule);
				} else if(oElm.currentStyle) {
					strCssRule = strCssRule.replace(/\-(\w)/g, function (strMatch, p1) {
						return p1.toUpperCase();
					});
					strValue = oElm.currentStyle[strCssRule];
				}

				return strValue;
			}

			function toggleButtonVisibility() {
				var htmlStyleVote = getStyle(document.getElementById('the-vote-buttons'), "display");
				var htmlStyleBoost = getStyle(document.getElementById('the-boost-buttons'), "display");

				if(htmlStyleVote == 'none' && htmlStyleBoost == 'inline-block') {
					document.getElementById('the-vote-buttons').style.display = 'inline-block';
					document.getElementById('the-boost-buttons').style.display = 'none';
				} else {
					document.getElementById('the-vote-buttons').style.display = 'none';
					document.getElementById('the-boost-buttons').style.display = 'inline-block';
				}
			}
			</script>

			<div class="icon32" id="icon-options-general"><br /></div>
			<h2><?php _e('Settings for WikioVote-Button', 'wikiovote_button'); ?></h2>
			<p><?php _e('This plugin will install the WikioVote-Button for each of your blog posts.', 'wikiovote_button'); ?></p>
			<form method="post" action="" id="wikiovote-button-options">
				<?php
				wp_nonce_field('wikiovote-button-options');
				$var_sWikioVoteOptions = wikiovote_button_get_option();
				?>
				<!-- Donate :-) -->
				<div style="float:right; text-align:center; width:120px;">
					<?php _e('Support me if you like the Plugin', 'wikiovote_button'); ?><br />
					<p>
						<a class="FlattrButton" style="display:none;" href="<?php echo WIKIOVOTE_DONATE_FLATTR_LINK; ?>"></a>
					</p>
					<p>
						<a class="PayPalButton" href="<?php echo WIKIOVOTE_DONATE_PAYPAL_LINK; ?>" target="_blank"><img src="https://www.paypalobjects.com/WEBSCR-640-20110401-1/en_GB/i/btn/btn_donate_SM.gif" /></a>
					</p>
				</div>

				<!-- Wikio TLD -->
				<div>
					<div style="display:inline-block; vertical-align:middle; width:200px;">
						<?php _e('Your Wikio', 'wikiovote_button'); ?>
					</div>
					<div style="display:inline-block; vertical-align:middle;">
						<div>
							<label for="wikiovote_button_display_page"><?php _e('http://www.wikio.', 'wikiovote_button'); ?></label>
							<input type="text" value="<?php echo htmlspecialchars($var_sWikioVoteOptions['wikiovote_button_tld']); ?>" name="wikiovote_button_tld" id="wikiovote_button_tld" style="width:50px;" />
						</div>
					</div>
				</div>

				<!-- Anzeige -->
				<div style="margin-top:15px;">
					<div style="display:inline-block; vertical-align:top; width:200px;">
						<?php _e('Display', 'wikiovote_button'); ?>
					</div>
					<div style="display:inline-block;">
						<div>
							<input type="checkbox" value="1" <?php if($var_sWikioVoteOptions['wikiovote_button_display_page'] == '1') echo 'checked="checked"'; ?> name="wikiovote_button_display_page" id="wikiovote_button_display_page" group="wikiovote_button_display" />
							<label for="wikiovote_button_display_page"><?php _e('Display the button on pages', 'wikiovote_button'); ?></label>
						</div>
						<div>
							<input type="checkbox" value="1" <?php if($var_sWikioVoteOptions['wikiovote_button_display_front'] == '1') echo 'checked="checked"'; ?> name="wikiovote_button_display_front" id="wikiovote_button_display_front" group="wikiovote_button_display" />
							<label for="wikiovote_button_display_front"><?php _e('Display the button on front page (home)', 'wikiovote_button'); ?></label>
						</div>
						<div>
							<input type="checkbox" value="1" <?php if($var_sWikioVoteOptions['wikiovote_button_display_archive'] == '1') echo 'checked="checked"'; ?> name="wikiovote_button_display_archive" id="wikiovote_button_display_archive" group="wikiovote_button_display" />
							<label for="wikiovote_button_display_archive"><?php _e('Display the button on archive-view <em>(<strong>Note</strong>: not all themes support this option)</em>', 'wikiovote_button'); ?></label>
						</div>
						<div>
							<input type="checkbox" value="1" <?php if($var_sWikioVoteOptions['wikiovote_button_display_category'] == '1') echo 'checked="checked"'; ?> name="wikiovote_button_display_category" id="wikiovote_button_display_category" group="wikiovote_button_display" />
							<label for="wikiovote_button_display_category"><?php _e('Display the button on category-view <em>(<strong>Note</strong>: not all themes support this option)</em>', 'wikiovote_button'); ?></label>
						</div>
						<div>
							<input type="checkbox" value="1" <?php if($var_sWikioVoteOptions['wikiovote_button_display_feed'] == '1') echo 'checked="checked"'; ?> name="wikiovote_button_display_feed" id="wikiovote_button_display_feed" group="wikiovote_button_display" />
							<label for="wikiovote_button_display_feed"><?php _e('Display the button on rss-feed', 'wikiovote_button'); ?></label>
						</div>
					</div>
				</div>

				<!-- Position -->
				<div style="margin-top:15px;">
					<div style="display:inline-block; vertical-align:middle; width:200px;">
						<?php _e('Position', 'wikiovote_button'); ?>
					</div>
					<div style="display:inline-block;">
						<select name="wikiovote_button_where">
							<option <?php if($var_sWikioVoteOptions['wikiovote_button_where'] == 'before') echo 'selected="selected"'; ?> value="before"><?php _e('Before', 'wikiovote_button'); ?></option>
							<option <?php if($var_sWikioVoteOptions['wikiovote_button_where'] == 'after') echo 'selected="selected"'; ?> value="after"><?php _e('After', 'wikiovote_button'); ?></option>
							<option <?php if($var_sWikioVoteOptions['wikiovote_button_where'] == 'beforeandafter') echo 'selected="selected"'; ?> value="beforeandafter"><?php _e('Before and After', 'wikiovote_button'); ?></option>
							<option <?php if($var_sWikioVoteOptions['wikiovote_button_where'] == 'shortcode') echo 'selected="selected"'; ?> value="shortcode"><?php _e('Shortcode [wikiobutton]', 'wikiovote_button'); ?></option>
							<option <?php if($var_sWikioVoteOptions['wikiovote_button_where'] == 'manual') echo 'selected="selected"'; ?> value="manual"><?php _e('Manual', 'wikiovote_button'); ?></option>
						</select>
					</div>
				</div>

				<!-- RSS-Position -->
				<div style="margin-top:15px;">
					<div style="display:inline-block; vertical-align:middle; width:200px;">
						<?php _e('RSS Position', 'wikiovote_button'); ?>
					</div>
					<div style="display:inline-block;">
						<select name="wikiovote_button_rss_where">
							<option <?php if($var_sWikioVoteOptions['wikiovote_button_rss_where'] == 'before') echo 'selected="selected"'; ?> value="before"><?php _e('Before', 'wikiovote_button'); ?></option>
							<option <?php if($var_sWikioVoteOptions['wikiovote_button_rss_where'] == 'after') echo 'selected="selected"'; ?> value="after"><?php _e('After', 'wikiovote_button'); ?></option>
							<option <?php if($var_sWikioVoteOptions['wikiovote_button_rss_where'] == 'beforeandafter') echo 'selected="selected"'; ?> value="beforeandafter"><?php _e('Before and After', 'wikiovote_button'); ?></option>
							<option <?php if($var_sWikioVoteOptions['wikiovote_button_where'] == 'shortcode') echo 'selected="selected"'; ?> value="shortcode"><?php _e('Shortcode [wikiobutton]', 'wikiovote_button'); ?></option>
						</select>
					</div>
				</div>

				<!-- Type -->
				<div style="margin-top:15px;">
					<div style="display:inline-block; vertical-align:top; width:200px;">
						<?php _e('Type', 'wikiovote_button'); ?>
						<div>
							<input type="radio" value="vote" <?php if($var_sWikioVoteOptions['wikiovote_button_type'] == 'vote') echo 'checked="checked"'; ?> name="wikiovote_button_type" id="wikiovote_button_type_votebutton" group="wikiovote_button_type" onchange=toggleButtonVisibility() />
							<label for="wikiovote_button_type_votebutton"><?php _e('Vote Button', 'wikiovote_button'); ?></label>
						</div>
						<div>
							<input type="radio" value="boost" <?php if($var_sWikioVoteOptions['wikiovote_button_type'] == 'boost') echo 'checked="checked"'; ?> name="wikiovote_button_type" id="wikiovote_button_type_boostbutton" group="wikiovote_button_type" onchange=toggleButtonVisibility() />
							<label for="wikiovote_button_type_boostbutton"><?php _e('Boost Button', 'wikiovote_button'); ?></label>
						</div>
					</div>

					<!--  Vote Buttons -->
					<div id="the-vote-buttons" style="<?php if($var_sWikioVoteOptions['wikiovote_button_type'] == 'vote') {echo 'display:inline-block;';} else {echo 'display:none;';} ?> vertical-align:top;">
						<div style="display:inline-block; vertical-align:top; width:180px;">
							<input type="radio" value="vertical" <?php if($var_sWikioVoteOptions['wikiovote_button_version'] == 'vertical') echo 'checked="checked"'; ?> name="wikiovote_button_version" id="wikiovote_button_version_vertical" group="wikiovote_button_version"/>
							<label for="wikiovote_button_version_large"><?php _e('Long button', 'wikiovote_button'); ?></label>
							<p><img src="<?php echo plugins_url(basename(dirname(__FILE__))); ?>/img/vote-large.jpg" /></p>
						</div>
						<div style="display:inline-block; vertical-align:top; width:180px;">
							<input type="radio" value="horizontal" <?php if($var_sWikioVoteOptions['wikiovote_button_version'] == 'horizontal') echo 'checked="checked"'; ?> name="wikiovote_button_version" id="wikiovote_button_version_horizontal" group="wikiovote_button_version" />
							<label for="wikiovote_button_version_horizontal"><?php _e('Big button', 'wikiovote_button'); ?></label>
							<p><img src="<?php echo plugins_url(basename(dirname(__FILE__))); ?>/img/vote-tall.jpg" /></p>
						</div>
						<div style="display:inline-block; vertical-align:top; width:180px; background-color:#ffebe8; border-color:#c00; border-radius: 3px 3px 3px 3px; border-style:solid; border-width:1px; margin:5px 15px 2px; padding:0 0.6em;">
							<span class="description">
								<?php
								_e('The support for this vote-button will be cancelled in futre times by wikio. Please use the boost-buttons.', 'wikiovote_button');
								?>
							</span>
						</div>
					</div>

					<!--  Boost Buttons -->
					<div id="the-boost-buttons" style="<?php if($var_sWikioVoteOptions['wikiovote_button_type'] == 'boost') {echo 'display:inline-block;';} else {echo 'display:none;';} ?> vertical-align:top;">
						<div style="display:inline-block; vertical-align:top; width:120px;">
							<input type="radio" value="squarewhite" <?php if($var_sWikioVoteOptions['wikiovote_button_version'] == 'squarewhite') echo 'checked="checked"'; ?> name="wikiovote_button_version" id="wikiovote_button_version_squarewhite" group="wikiovote_button_version"/>
							<label for="wikiovote_button_version_squarewhite"><?php _e('Square white', 'wikiovote_button'); ?></label>
							<p style="text-align:center;"><img src="<?php echo plugins_url(basename(dirname(__FILE__))); ?>/img/wikio-buttons-vote-squarewhite.png" /></p>
						</div>
						<div style="display:inline-block; vertical-align:top; width:120px;">
							<input type="radio" value="squareblue" <?php if($var_sWikioVoteOptions['wikiovote_button_version'] == 'squareblue') echo 'checked="checked"'; ?> name="wikiovote_button_version" id="wikiovote_button_version_squareblue" group="wikiovote_button_version" />
							<label for="wikiovote_button_version_squareblue"><?php _e('Square blue', 'wikiovote_button'); ?></label>
							<p style="text-align:center;"><img src="<?php echo plugins_url(basename(dirname(__FILE__))); ?>/img/wikio-buttons-vote-squareblue.png" /></p>
						</div>
						<div style="display:inline-block; vertical-align:top; width:120px;">
							<input type="radio" value="capsulewhite" <?php if($var_sWikioVoteOptions['wikiovote_button_version'] == 'capsulewhite') echo 'checked="checked"'; ?> name="wikiovote_button_version" id="wikiovote_button_version_capsulewhite" group="wikiovote_button_version" />
							<label for="wikiovote_button_version_capsulewhite"><?php _e('Capsule white', 'wikiovote_button'); ?></label>
							<p style="text-align:center;"><img src="<?php echo plugins_url(basename(dirname(__FILE__))); ?>/img/wikio-buttons-vote-capsulewhite.png" /></p>
						</div>
						<div style="display:inline-block; vertical-align:top; width:120px;">
							<input type="radio" value="capsuleblue" <?php if($var_sWikioVoteOptions['wikiovote_button_version'] == 'capsuleblue') echo 'checked="checked"'; ?> name="wikiovote_button_version" id="wikiovote_button_version_capsuleblue" group="wikiovote_button_version" />
							<label for="wikiovote_button_version_capsuleblue"><?php _e('Capsule blue', 'wikiovote_button'); ?></label>
							<p style="text-align:center;"><img src="<?php echo plugins_url(basename(dirname(__FILE__))); ?>/img/wikio-buttons-vote-capsuleblue.png" /></p>
						</div>
						<div style="display:inline-block; vertical-align:top; width:120px;">
							<input type="radio" value="styleold2" <?php if($var_sWikioVoteOptions['wikiovote_button_version'] == 'styleold2') echo 'checked="checked"'; ?> name="wikiovote_button_version" id="wikiovote_button_version_wikioicon" group="wikiovote_button_version" />
							<label for="wikiovote_button_version_wikioicon"><?php _e('Wikio Icon', 'wikiovote_button'); ?></label>
							<p style="text-align:center;"><img src="<?php echo plugins_url(basename(dirname(__FILE__))); ?>/img/wikio-icon.png" /></p>
						</div>
					</div>
				</div>

				<!-- Styling -->
				<div>
					<div style="display:inline-block; vertical-align:middle; width:200px;">
						<?php _e('Styling', 'wikiovote_button'); ?>
					</div>
					<div style="display:inline-block; vertical-align:middle;">
						<div>
							<input type="text" value="<?php echo htmlspecialchars($var_sWikioVoteOptions['wikiovote_button_style']); ?>" name="wikiovote_button_style" id="wikiovote_button_style" />
							<span class="description"><?php _e('Add style to the div that surrounds the button E.g. <code>float: left; margin-right: 10px;</code>', 'wikiovote_button'); ?></span>
						</div>
					</div>
				</div>

				<p class="submit">
					<input type="submit" name="Submit" value="<?php _e('Save Changes', 'wikiovote_button'); ?>" />
				</p>
			</form>
		</div>
	<?php
	}
}

/**
 * Standardwerte setzen.
 */
if(!function_exists('wikiovote_button_activate')) {
	function wikiovote_button_activate() {
		if(!is_array(get_option('wikiovote-button-options'))) {
			add_option('wikiovote-button-options', wikiovote_button_get_default_options());
		} else {
			$array_OptionsOld = wikiovote_button_get_option();

			if($array_OptionsOld['wikiovote_button_pluginversion'] != WIKIOVOTE_BUTTON_VERSION) {
				$array_OptionsOld['wikiovote_button_pluginversion'] = WIKIOVOTE_BUTTON_VERSION;

				wikiovote_button_update_options($array_OptionsOld);
				return;
			}

			return;
		}
	}
}

/**
 * Optionen registrieren.
 * Sprachdatei initialisieren.
 *
 * @since 1.3.0
 */
if(!function_exists('wikiovote_button_init')) {
	function wikiovote_button_init() {
		if(function_exists('register_setting')) {
			register_setting('wikiovote-button-options', 'wikiovote-button-options');
		}

		/**
		 * Sprachdatei wählen
		 */
		if(function_exists('load_plugin_textdomain')) {
			load_plugin_textdomain('wikiovote_button', false, dirname(plugin_basename( __FILE__ )) . '/l10n/');
		}
	}
}

/**
 * Links zur Pluginübersicht hinzufügen.
 *
 * @since 1.3.0
 */
if(!function_exists('wikiovote_button_settings_link')) {
	function wikiovote_button_settings_link($links, $file) {
	 	if($file == 'wikiovote-button/wikiovote-button.php' && function_exists("admin_url")) {
			$settings_link = '<a href="' . admin_url('options-general.php?page=wikiovote-button-options') . '">' . __('Settings') . '</a>';
			array_unshift($links, $settings_link); // before the other links

			/**
			 * Link zum Updaten der Optionen.
			 *
			 * @since 2.0.0
			 */
			if(!is_array(get_option('wikiovote-button-options'))) {
				$settings_link_update_options = '<a href="' . admin_url('options-general.php?page=wikiovote-button-options&option=update_db') . '">' . __('Update Options', 'wikiovote_button') . '</a>';
				array_unshift($links, $settings_link_update_options); // before the other links
			}
		}

		return $links;
	}
}

/**
 * Optionen updaten ...
 * @param array $array_Data
 *
 * @since 2.0.0
 */
if(!function_exists('wikiovote_button_update_options')) {
	function wikiovote_button_update_options($array_Data) {
		$array_Options = array_merge((array) get_option('wikiovote-button-options'), $array_Data);

		update_option('wikiovote-button-options', $array_Options);
		wp_cache_set('wikiovote-button-options', $array_Options);

		return;
	}
}

/**
 * Datenbankoptionen updaten, falls benötigt.
 * Dies kann nach einem Pluginupdate nötig sein.
 *
 * WICHTIG !!!
 * Diese Funktion wird NICHT verwendet um die Einstellungen zu aktualisieren,
 * sondern um das Format der Optionen in der Datenbank bei Pluginupdates anzupassen.
 *
 * @since 2.0.0
 */
if(!function_exists('wikiovote_button_update_databaseformat')) {
	function wikiovote_button_update_databaseformat() {
		$array_WikioOptions = array(
			'wikiovote_button_pluginversion' => (string) WIKIOVOTE_BUTTON_VERSION,
			'wikiovote_button_tld' => (string) 'de',
			'wikiovote_button_type' => (string) 'vote',
			'wikiovote_button_version' => '',
			'wikiovote_button_where' => '',
			'wikiovote_button_rss_where' => '',
			'wikiovote_button_style' => '',
			'wikiovote_button_display_page' => '',
			'wikiovote_button_display_front' => '',
			'wikiovote_button_display_archive' => '',
			'wikiovote_button_display_category' => '',
			'wikiovote_button_display_feed' => '',
		);

		foreach($array_WikioOptions as $key => $value) {
			$array_WikioOptions[$key] = (get_option($key)) ? get_option($key) : $value;
			delete_option($key);
		}

		update_option('wikiovote-button-options', $array_WikioOptions);

		return;
	}
}

/**
 * Setze Default-Options für das Plugin.
 *
 * @since 2.0.0
 */
if(!function_exists('wikiovote_button_get_default_options')) {
	function wikiovote_button_get_default_options() {
		$array_OptionsDefault = array(
			'wikiovote_button_pluginversion' => (string) WIKIOVOTE_BUTTON_VERSION,
			'wikiovote_button_tld' => (string) 'de',
			'wikiovote_button_type' => (string) 'vote',
			'wikiovote_button_version' => (string) 'vertical',
			'wikiovote_button_where' => (string) 'before',
			'wikiovote_button_rss_where' => (string) 'before',
			'wikiovote_button_style' => (string) 'float:right; margin-left:10px;',
			'wikiovote_button_display_page' => (int) '1',
			'wikiovote_button_display_front' => (int) '0',
			'wikiovote_button_display_archive' => (int) '0',
			'wikiovote_button_display_category' => (int) '0',
			'wikiovote_button_display_feed' => (int) '0'
		);

		return $array_OptionsDefault;
	}
}

/**
 * Manuelle Ausgabe.
 *
 * @since 1.0.0
 */
if(!function_exists('wikiovote_button')) {
	function wikiovote_button() {
		global $var_sWikioVoteOptions;

		if($var_sWikioVoteOptions['wikiovote_button_where'] == 'manual') {
			return wikiovote_button_generate_button();
		} else {
			return false;
		}
	}
}

/**
 * Filter durch Vorschau entfernen.
 *
 * @param string $content
 * @since 1.0.0
 */
if(!function_exists('wikiovote_button_remove_filter')) {
	function wikiovote_button_remove_filter($content) {
		if(!is_feed()) {
			remove_action('the_content', 'wikiovote_button_update');
		}
		return $content;
	}
}

/**
 * Meta-Tag 'wikiovote_button-title' setzen.
 *
 * @since 1.0.0
 */
if(!function_exists('wikiovote_button_head')) {
	function wikiovote_button_head() {
		global $var_sWikioVoteOptions;

		/**
		 * Sind wir in einem Artikel?
		 */
		if(is_single()) {
			global $post;
			$title = get_the_title($post->ID);
			echo '<!-- WikioVote-Button by H.-Peter Pfeufer -->' . "\n" . '<meta name="wikiovote_button-title" content="' . strip_tags($title) . '" />' . "\n";
		}

		if(!is_admin()) {
			$images_url = plugins_url(basename(dirname(__FILE__)) . '/img/');
			$css_url = plugins_url(basename(dirname(__FILE__)) . '/css/wikiovote-button.css?ver=' . WIKIOVOTE_BUTTON_VERSION);

			/**
			 * CSS in Wordpress einbinden.
			 */
			echo '<link rel="stylesheet" id="wikiovotebutton-for-wordpress"  href="' . $css_url . '" type="text/css" media="all" />' . "\n";
		}
	}
}

/**
 * Hier wird der Content verarbeiten und der Button an die gewünschte Stelle gesetzt.
 *
 * @since 1.0.0
 */
if(!function_exists('wikiovote_button_update')) {
	function wikiovote_button_update($content) {
		global $post;
		global $var_sWikioVoteOptions;

		/**
		 * Manual Option.
		 */
		if($var_sWikioVoteOptions['wikiovote_button_where'] == 'manual') {
			return $content;
		}

		/**
		 * Sind wir auf einer CMS-Seite?
		 */
		if($var_sWikioVoteOptions['wikiovote_button_display_page'] == null && is_page()) {
			return $content;
		}

		/**
		 * Sind wir auf der Startseite?
		 */
		if($var_sWikioVoteOptions['wikiovote_button_display_front'] == null && is_home()) {
			return $content;
		}

		/**
		 * Sind wir in der Achiveanzeige?
		 */
		if($var_sWikioVoteOptions['wikiovote_button_display_archive'] == null && is_archive()) {
			return $content;
		}

		/**
		 * Sind wir in der Kategorieanzeige?
		 */
		if($var_sWikioVoteOptions['wikiovote_button_display_category'] == null && is_category()) {
			return $content;
		}

		/**
		 * Ist es ein Feed?
		 */
		if(is_feed()) {
			$button = wikiovote_button_generate_rss_button($var_sWikioVoteOptions['wikiovote_button_type']);
			$where = 'wikiovote_button_rss_where';
		} else {
			$button = wikiovote_button_generate_button($var_sWikioVoteOptions['wikiovote_button_type']);
			$where = 'wikiovote_button_where';
		}

		/**
		 * Soll der Button im Feed ausgeblendet werden?
		 */
		if(is_feed() && $var_sWikioVoteOptions['wikiovote_button_display_feed'] == null) {
			return $content;
		}

		/**
		 * Wurde der Shortcode genutzt?
		 */
		if($var_sWikioVoteOptions[$where] == 'shortcode') {
			return str_replace('[wikiobutton]', $button, $content);
		} else {
			if(get_post_meta($post->ID, 'wikiovote_button') == null) {
				if($var_sWikioVoteOptions[$where] == 'beforeandafter') {
					/**
					 * Vor und nach dem Beitrag einfügen
					 */
					return $button . $content . $button;
				} else if($var_sWikioVoteOptions[$where] == 'before') {
					/**
					 * Vor dem Beitrag einfügen
					 */
					return $button . $content;
				} else {
					/**
					 * Nach dem Beitrag einfügen
					 */
					return $content . $button;
				}
			} else {
				/**
				 * Keinen Button einfügen
				 */
				return $content;
			}
		}
	}
}

/**
 * Hilfsfunktin für den alten Votebutton.
 *
 * @since 1.0.0
 */
if(!function_exists('wikiovote_button_wikinote')) {
	function wikiovote_button_wikinote() {
		global $var_sWikioVoteOptions;

		$wikioThisUrl = htmlspecialchars(strip_tags(get_permalink()), ENT_QUOTES);
		$wikioReferer = htmlspecialchars(strip_tags('http://' . $_SERVER['HTTP_HOST'] . $_SERVER['REQUEST_URI']), ENT_QUOTES);

		if(isset($_SERVER['HTTP_X_FORWARDED_FOR'])) {
			$wikioCliIp = $_SERVER['HTTP_X_FORWARDED_FOR'];
		} elseif(isset($_SERVER['HTTP_CLIENT_IP'])) {
			$wikioCliIp = $_SERVER['HTTP_CLIENT_IP'];
		} else {
			$wikioCliIp = $_SERVER['REMOTE_ADDR'];
		}

		$wikioSuffix = $var_sWikioVoteOptions['wikiovote_button_tld'];
		$wikioUrl = "web.wikio." . $wikioSuffix;
		$wikioSuffix = "";
		$wikioNote = 0;

		$wikioId = 0;
		$wikioPattern1 = "";
		$wikioPattern2 = "";
		$wikioPattern3 = "/article=";
		$wikiohasVoted = "";
		$bVoted = 0;
		$wikioAllowVote = 1;

		$ch = curl_init();
		$timeout = 5; // set to zero for no timeout
		curl_setopt($ch, CURLOPT_URL, "http://" . $wikioUrl . $wikioSuffix . "/getnote?u=" . MD5($wikioThisUrl) . "&i=" . $wikioCliIp . "&referer=" . MD5($wikioReferer));
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
		curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, $timeout);
		$wikioNote = curl_exec($ch);
		curl_close($ch);

		return $wikioNote;
	}
}

/**
 * Button für WordPress erzeugen.
 *
 * @since 1.0.0
 */
if(!function_exists('wikiovote_button_generate_button')) {
	function wikiovote_button_generate_button($var_sType = '') {
		global $var_sWikioVoteOptions;

		$url = get_permalink();

		switch($var_sType) {
			/**
			 * Wikio Boost Button.
			 *
			 * @since 2.0.0
			 */
			case 'boost':
				$wikiobutton = '<script src="http://www.wikio.' . $var_sWikioVoteOptions['wikiovote_button_tld'] . '/getvote?style=' . $var_sWikioVoteOptions['wikiovote_button_version'] . '&url=' . urlencode($url) . '" type="text/javascript"></script>';

				return '<div class="wp_wikio_button_' . $var_sWikioVoteOptions['wikiovote_button_version'] . '" style="' . $var_sWikioVoteOptions['wikiovote_button_style'] . '">' . $wikiobutton . '</div>';
				break;

			/**
			 * WikioVote Button.
			 *
			 * @since 1.0.0
			 */
			case 'vote':
				$wikioNote = wikiovote_button_wikinote();

				$wikioId = 0;
				$wikioPattern1 = "";
				$wikioPattern2 = "";
				$wikioPattern3 = "/article=";
				$wikiohasVoted = "";
				$bVoted = 0;
				$wikioAllowVote = 1;

				if($wikioNote) {
					if(ereg("([0-9]*)\|([0-9]*)\|(.*)\|(.*)\|([0-9]*)\|(.*)\|([0-9]*)\|", $wikioNote, $res)) {
						$wikioNote = $res[1];
						$wikioId = $res[2];
						$wikioPattern1 = ($res[5] == 1) ? $res[4] : $res[3];
						$wikioPattern2 = $res[4];
						$wikiohasVoted = ($res[5] == 0 && $res[7] == 1) ? "&amp;vote=1" : "";
						$bVoted = $res[5];
						$wikioSuffix = $res[6];
						$wikioAllowVote = $res[7];
					}
				}

				if ($var_sWikioVoteOptions['wikiovote_button_version'] == 'vertical') {
					$wikioUrl = "www.wikio." . $wikioSuffix;

					if($wikioId > 0) {
						$wikiobutton = "<script type=\"text/javascript\">
							var wikiovoted=false;
							function setWikio(){";
						if($wikioAllowVote > 0 && $bVoted == 0) {
							$wikiobutton .= "t=top.document;
							if(!wikiovoted){n=t.getElementById('wikioNote1');a=t.getElementById('wikioAction1');
							if(n && !isNaN(parseInt(n.innerHTML)))n.innerHTML=parseInt(n.innerHTML)+1;if(a)a.innerHTML='" . $wikioPattern2 . "';
							}
							wikiovoted=true;";
						}
						$wikiobutton .= "}
							</script>";

						// Code Button lang
						$wikiobutton .= '<div class="wikiobutton1">';
						$wikiobutton .= '<div class="wikioaction1">';
						$wikiobutton .= '<a href="http://' . $wikioUrl . $wikioPattern3 . $wikioId . $wikiohasVoted . '" target="_blank" id="wikioAction1" onclick="setWikio();">' . $wikioPattern1 . '</a>';
						$wikiobutton .= '</div>';
						$wikiobutton .= '<a class="wikiokurz wikiolink" href="http://' . $wikioUrl . $wikioPattern3 . $wikioId . $wikiohasVoted . '" target="_blank" onclick="setWikio();">';
						$wikiobutton .= '<div class="wikiovote1" align="center" id="wikioNote1">' . $wikioNote . '</div>';
						$wikiobutton .= '</a>';
						$wikiobutton .= '</div>';
					}
				} else {
					$wikioUrl = "www.wikio." . $wikioSuffix;
					$images_url = plugins_url(basename(dirname(__FILE__)) . '/img/');

					if($wikioId > 0) {
						$wikiobutton = "<script type=\"text/javascript\">
							var wikiovoted=false;
							function setWikio(id){";

						if($wikioAllowVote > 0 && $bVoted == 0) {
							$wikiobutton .= "var t=top.document;
							if(!wikiovoted){
								var n=t.getElementById('wikionote_:' + id);
								var a=t.getElementById('wikioaction_' + id);
								if(n && !isNaN(parseInt(n.innerHTML))){
									n.innerHTML=parseInt(n.innerHTML)+1
								}
								if(a){
									a.innerHTML='" . $wikioPattern2 . "'
								};
							}
							wikiovoted=true;";
						}

						$wikiobutton .= "}
							</script>";

						// Code Button gross
						$wikiobutton .= '<div class="wikiobutton">';
						$wikiobutton .= '<div class="wikiotxt wbutton"><div class="wikionote">';
						$wikiobutton .= '<a id="wikionote_' . $wikioId . '" href="http://' . $wikioUrl . $wikioPattern3 . $wikioId . $wikiohasVoted . '" class="wikioaction" target="_blank" onclick="setWikio(' . $wikioId . ');">' . $wikioNote . '</a>';
						$wikiobutton .= '</div>';
						$wikiobutton .= '<div class="wikioaction">';
						$wikiobutton .= '<a href="http://' . $wikioUrl . $wikioPattern3 . $wikioId . $wikiohasVoted . '" class="wikioaction" id="wikioaction_' . $wikioId . '" target="_blank" onclick="setWikio(this.id);">' . $wikioPattern1 . '</a>';
						$wikiobutton .= '</div>';
						$wikiobutton .= '</div>';
						$wikiobutton .= '<div class="wikio">';
						$wikiobutton .= '<a href="http://' . $wikioUrl . '" target="_blank" class="wikioimg">';
						$wikiobutton .= '<img src="' . $images_url . 'wikio.gif" alt="www.wikio.' . $wikioSuffix . '" border="0" width="45" height="15" /></a>';
						$wikiobutton .= '</div>';
						$wikiobutton .= '</div>';
					}
				}

				return '<div class="wp_wikio_button_id_' . $wikioId . '" style="' . $var_sWikioVoteOptions['wikiovote_button_style'] . '">' . $wikiobutton . '</div>';
				break;
		}
	}
}

/**
 * Button für RSS
 *
 * @since 1.0.0
 */
if(!function_exists('wikiovote_button_generate_rss_button')) {
	function wikiovote_button_generate_rss_button($var_sType = '') {
		if(get_post_status($post->ID) == 'publish') {
			global $var_sWikioVoteOptions;

			$url = get_permalink();

			switch($var_sType) {
				/**
				 * Wikio Boost Button.
				 *
				 * @since 2.0.0
				 */
				case 'boost':
					$wikiobutton = '<script src="http://www.wikio.' . $var_sWikioVoteOptions['wikiovote_button_tld'] . '/getvote?style=' . $var_sWikioVoteOptions['wikiovote_button_version'] . '&url=' . urlencode($url) . '" type="text/javascript"></script>';

					return '<div class="wp_wikio_button_' . $var_sWikioVoteOptions['wikiovote_button_version'] . '" style="' . $var_sWikioVoteOptions['wikiovote_button_style'] . '">' . $wikiobutton . '</div>';
					break;

				/**
				 * WikioVote Button.
				 *
				 * @since 1.0.0
				 */
				case 'vote':
					$wikioNote = wikiovote_button_wikinote();

					$wikioId = 0;
					$wikioPattern1 = "";
					$wikioPattern2 = "";
					$wikioPattern3 = "/article=";
					$wikiohasVoted = "";
					$bVoted = 0;
					$wikioAllowVote = 1;

					if($wikioNote) {
						if(ereg("([0-9]*)\|([0-9]*)\|(.*)\|(.*)\|([0-9]*)\|(.*)\|([0-9]*)\|", $wikioNote, $res)) {
							$wikioNote = $res[1];
							$wikioId = $res[2];
							$wikioPattern1 = ($res[5] == 1) ? $res[4] : $res[3];
							$wikioPattern2 = $res[4];
							$wikiohasVoted = ($res[5] == 0 && $res[7] == 1) ? "&amp;vote=1" : "";
							$bVoted = $res[5];
							$wikioSuffix = $res[6];
							$wikioAllowVote = $res[7];
						}
					}

					if ($var_sWikioVoteOptions['wikiovote_button_version'] == 'vertical') {
						$wikioUrl = "www.wikio." . $wikioSuffix;

						if($wikioId > 0) {
							$wikiobutton = "<script type=\"text/javascript\">
								var wikiovoted=false;
								function setWikio(){";
							if($wikioAllowVote > 0 && $bVoted == 0) {
								$wikiobutton .= "t=top.document;
								if(!wikiovoted){n=t.getElementById('wikioNote1');a=t.getElementById('wikioAction1');
								if(n && !isNaN(parseInt(n.innerHTML)))n.innerHTML=parseInt(n.innerHTML)+1;if(a)a.innerHTML='" . $wikioPattern2 . "';
								}
								wikiovoted=true;";
							}
							$wikiobutton .= "}
								</script>";

							// Code Button lang
							$wikiobutton .= '<div class="wikiobutton1">';
							$wikiobutton .= '<div class="wikioaction1">';
							$wikiobutton .= '<a href="http://' . $wikioUrl . $wikioPattern3 . $wikioId . $wikiohasVoted . '" target="_blank" id="wikioAction1" onclick="setWikio();">' . $wikioPattern1 . '</a>';
							$wikiobutton .= '</div>';
							$wikiobutton .= '<a class="wikiokurz" href="http://' . $wikioUrl . $wikioPattern3 . $wikioId . $wikiohasVoted . '" class="wikiolink" target="_blank" onclick="setWikio();">';
							$wikiobutton .= '<div class="wikiovote1" align="center" id="wikioNote1">' . $wikioNote . '</div>';
							$wikiobutton .= '</a>';
							$wikiobutton .= '</div>';
						}
					} else {
						$wikioUrl = "www.wikio." . $wikioSuffix;
						$images_url = plugins_url(basename(dirname(__FILE__)) . '/img/');

						if($wikioId > 0) {
							$wikiobutton = "<script type=\"text/javascript\">
								var wikiovoted=false;
								function setWikio(id){";

							if($wikioAllowVote > 0 && $bVoted == 0) {
								$wikiobutton .= "var t=top.document;
								if(!wikiovoted){
									var n=t.getElementById('wikionote_:' + id);
									var a=t.getElementById('wikioaction_' + id);
									if(n && !isNaN(parseInt(n.innerHTML))){
										n.innerHTML=parseInt(n.innerHTML)+1
									}
									if(a){
										a.innerHTML='" . $wikioPattern2 . "'
									};
								}
								wikiovoted=true;";
							}

							$wikiobutton .= "}
								</script>";

							// Code Button gross
							$wikiobutton .= '<div class="wikiobutton">';
							$wikiobutton .= '<div class="wikiotxt wbutton">';
							$wikiobutton .= '<div class="wikionote">';
							$wikiobutton .= '<a id="wikionote_' . $wikioId . '" href="http://' . $wikioUrl . $wikioPattern3 . $wikioId . $wikiohasVoted . '" class="wikioaction" target="_blank" onclick="setWikio(' . $wikioId . ');">' . $wikioNote . '</a>';
							$wikiobutton .= '</div>';
							$wikiobutton .= '<div class="wikioaction">';
							$wikiobutton .= '<a href="http://' . $wikioUrl . $wikioPattern3 . $wikioId . $wikiohasVoted . '" class="wikioaction" id="wikioaction_' . $wikioId . '" target="_blank" onclick="setWikio(this.id);">' . $wikioPattern1 . '</a>';
							$wikiobutton .= '</div>';
							$wikiobutton .= '</div>';
							$wikiobutton .= '<div class="wikio">';
							$wikiobutton .= '<a href="http://' . $wikioUrl . '" target="_blank" class="wikioimg">';
							$wikiobutton .= '<img src="' . $images_url . 'wikio.gif" alt="www.wikio.' . $wikioSuffix . '" border="0" width="45" height="15" />';
							$wikiobutton .= '</a>';
							$wikiobutton .= '</div>';
							$wikiobutton .= '</div>';
						}
					}

					return '<div class="wp_wikio_button_id_' . $wikioId . '" style="' . $var_sWikioVoteOptions['wikiovote_button_style'] . '">' . $wikiobutton . '</div>';
					break;
			}
		} else {
			return;
		}
	}
}

/**
 * Hooks bedienen und Filter zu WordPress hinzufügen.
 */
/* Button aktivieren */
register_activation_hook(__FILE__, 'wikiovote_button_activate');

/**
 * Nur wenn User auch der Admin ist, sind die Adminoptionen zu sehen
 */
if(is_admin()) {
	add_action('admin_menu', 'wikiovote_button_options');
	add_action('admin_init', 'wikiovote_button_init');
}

/* Optionsseite in Pluginübersicht einbinden */
add_filter('plugin_action_links', 'wikiovote_button_settings_link', 9, 2 );

/* Filter */
add_filter('the_content', 'wikiovote_button_update', 8);
add_filter('get_the_excerpt', 'wikiovote_button_remove_filter', 9);

/* Header erweitern */
add_action('wp_head', 'wikiovote_button_head');
?>